@@ -17,59 +17,60 @@
 
 import hashlib
 
-from logilab.common.decorators import cachedproperty
-
 from cubicweb.utils import json_dumps
 
 
 class RqlIOSchemaHolder(object):
     """Class used to load the schema and its hash.
-       Both can be fetched by the client via dedicated views,
-       so it can decide to update the locally stored schema if
-       the integrity is not valid.
+    Both can be fetched by the client via dedicated views,
+    so it can decide to update the locally stored schema if
+    the integrity is not valid.
     """
+
     _schema = None
     _hash = None
 
     @staticmethod
-    def format_schema(typeNames,
-                      specializes,
-                      attributeNames,
-                      relationsTo,
-                      relationsFrom):
+    def format_schema(
+        typeNames, specializes, attributeNames, relationsTo, relationsFrom
+    ):
         return {
             "eid": typeNames[0][0],
             "name": typeNames[0][1],
             "modificationDate": typeNames[0][2].strftime("%Y/%m/%d %H:%M:%S"),
             "specializes": specializes[0][0] if specializes else None,
-            "attributes": [{
-                "eid": row[0],
-                "name": row[1],
-                "type": row[2],
-                "cardinality": row[3]
-            } for row in attributeNames],
-            "relationsTo": [{
-                "eid": row[0],
-                "name": row[1],
-                "from": row[2],
-                "fromName": typeNames[0][1],
-                "fromCardinality": row[6],
-                "to": row[3],
-                "toName": row[4],
-                "toCardinality": row[6],
-                "description": row[5]
-            } for row in relationsTo],
-            "relationsFrom": [{
-                "eid": row[0],
-                "name": row[1],
-                "from": row[2],
-                "fromName": row[3],
-                "fromCardinality": row[6],
-                "to": row[4],
-                "toName": typeNames[0][1],
-                "toCardinality": row[6],
-                "description": row[5]
-            } for row in relationsFrom]
+            "attributes": [
+                {"eid": row[0], "name": row[1], "type": row[2], "cardinality": row[3]}
+                for row in attributeNames
+            ],
+            "relationsTo": [
+                {
+                    "eid": row[0],
+                    "name": row[1],
+                    "from": row[2],
+                    "fromName": typeNames[0][1],
+                    "fromCardinality": row[6],
+                    "to": row[3],
+                    "toName": row[4],
+                    "toCardinality": row[6],
+                    "description": row[5],
+                }
+                for row in relationsTo
+            ],
+            "relationsFrom": [
+                {
+                    "eid": row[0],
+                    "name": row[1],
+                    "from": row[2],
+                    "fromName": row[3],
+                    "fromCardinality": row[6],
+                    "to": row[4],
+                    "toName": typeNames[0][1],
+                    "toCardinality": row[6],
+                    "description": row[5],
+                }
+                for row in relationsFrom
+            ],
         }
 
     @classmethod
@@ -78,17 +79,15 @@ class RqlIOSchemaHolder(object):
             return cls._schema
 
         entities = []
-        etypes = cnx.execute('Any T WHERE T is CWEType')
+        etypes = cnx.execute("Any T WHERE T is CWEType")
         for etype in etypes:
             eid = etype[0]
             rql_requests = [
                 (
-                    f'Any TYPE,NAME,MD WHERE TYPE eid {eid}, TYPE name NAME, '
-                    'TYPE modification_date MD'
-                ),
-                (
-                    f'Any PARENT WHERE TYPE eid {eid}, TYPE specializes PARENT'
+                    f"Any TYPE,NAME,MD WHERE TYPE eid {eid}, TYPE name NAME, "
+                    "TYPE modification_date MD"
                 ),
+                (f"Any PARENT WHERE TYPE eid {eid}, TYPE specializes PARENT"),
                 (
                     f"""Any ATTR,NAME,ATTRTYPENAME,CARD ORDERBY ON WHERE TYPE eid {eid},
                     ATTR from_entity TYPE,
@@ -125,7 +124,7 @@ class RqlIOSchemaHolder(object):
                     ATTR is CWRelation,
                     ATTR cardinality CARD?,
                     ATTR ordernum ON"""
-                )
+                ),
             ]
             rsets = [cnx.execute(request) for request in rql_requests]
             entities.append(RqlIOSchemaHolder.format_schema(*rsets))
